@@ -39,9 +39,10 @@ use strict;
 use Archive::Zip qw( :ERROR_CODES :CONSTANTS );
 
 use vars qw{$VERSION};
+
 BEGIN {
-	$VERSION = '1.17_03';
-	$VERSION = eval $VERSION;
+    $VERSION = '1.17_05';
+    $VERSION = eval $VERSION;
 }
 
 =item Archive::Zip::Member::readFileHandle()
@@ -59,9 +60,8 @@ calling C<readFileHandle()>:
 
 =cut
 
-sub Archive::Zip::Member::readFileHandle
-{
-	return Archive::Zip::MemberRead->new( shift () );
+sub Archive::Zip::Member::readFileHandle {
+    return Archive::Zip::MemberRead->new( shift() );
 }
 
 =item Archive::Zip::MemberRead->new($zip, $fileName)
@@ -76,45 +76,41 @@ Construct a new Archive::Zip::MemberRead on the specified member.
 
 =cut
 
-sub new
-{
-	my ( $class, $zip, $file ) = @_;
-	my ( $self, $member );
+sub new {
+    my ( $class, $zip, $file ) = @_;
+    my ( $self, $member );
 
-	if ( $zip && $file )    # zip and filename, or zip and member
-	{
-		$member = ref($file) ? $file : $zip->memberNamed($file);
-	}
-	elsif ( $zip && !$file && ref($zip) )    # just member
-	{
-		$member = $zip;
-	}
-	else
-	{
-		die (
+    if ( $zip && $file )    # zip and filename, or zip and member
+    {
+        $member = ref($file) ? $file : $zip->memberNamed($file);
+    }
+    elsif ( $zip && !$file && ref($zip) )    # just member
+    {
+        $member = $zip;
+    }
+    else {
+        die(
 'Archive::Zip::MemberRead::new needs a zip and filename, zip and member, or member'
-		);
-	}
+        );
+    }
 
-	$self = {};
-	bless( $self, $class );
-	$self->set_member($member);
-	return $self;
+    $self = {};
+    bless( $self, $class );
+    $self->set_member($member);
+    return $self;
 }
 
-sub set_member
-{
-	my ( $self, $member ) = @_;
+sub set_member {
+    my ( $self, $member ) = @_;
 
-	$self->{member} = $member;
-	$self->set_compression(COMPRESSION_STORED);
-	$self->rewind();
+    $self->{member} = $member;
+    $self->set_compression(COMPRESSION_STORED);
+    $self->rewind();
 }
 
-sub set_compression
-{
-	my ( $self, $compression ) = @_;
-	$self->{member}->desiredCompressionMethod($compression) if $self->{member};
+sub set_compression {
+    my ( $self, $compression ) = @_;
+    $self->{member}->desiredCompressionMethod($compression) if $self->{member};
 }
 
 =item rewind()
@@ -124,20 +120,18 @@ starting at the beginning.
 
 =cut
 
-sub rewind
-{
-	my $self = shift;
+sub rewind {
+    my $self = shift;
 
-	$self->_reset_vars();
-	$self->{member}->rewindData() if $self->{member};
+    $self->_reset_vars();
+    $self->{member}->rewindData() if $self->{member};
 }
 
-sub _reset_vars
-{
-	my $self = shift;
-	$self->{lines}   = [];
-	$self->{partial} = 0;
-	$self->{line_no} = 0;
+sub _reset_vars {
+    my $self = shift;
+    $self->{lines}   = [];
+    $self->{partial} = 0;
+    $self->{line_no} = 0;
 }
 
 =item input_line_number()
@@ -147,10 +141,9 @@ Using C<read()> will not update the line number.
 
 =cut
 
-sub input_line_number
-{
-	my $self = shift;
-	return $self->{line_no};
+sub input_line_number {
+    my $self = shift;
+    return $self->{line_no};
 }
 
 =item close()
@@ -159,12 +152,11 @@ Closes the given file handle.
 
 =cut
 
-sub close
-{
-	my $self = shift;
+sub close {
+    my $self = shift;
 
-	$self->_reset_vars();
-	$self->{member}->endRead();
+    $self->_reset_vars();
+    $self->{member}->endRead();
 }
 
 =item buffer_size([ $size ])
@@ -174,18 +166,15 @@ Default is the chunk size used by Archive::Zip.
 
 =cut
 
-sub buffer_size
-{
-	my ( $self, $size ) = @_;
+sub buffer_size {
+    my ( $self, $size ) = @_;
 
-	if ( !$size )
-	{
-		return $self->{chunkSize} || Archive::Zip::chunkSize();
-	}
-	else
-	{
-		$self->{chunkSize} = $size;
-	}
+    if ( !$size ) {
+        return $self->{chunkSize} || Archive::Zip::chunkSize();
+    }
+    else {
+        $self->{chunkSize} = $size;
+    }
 }
 
 =item getline()
@@ -201,40 +190,36 @@ Note: The line returned has the newline removed.
 
 # $self->{partial} flags whether the last line in the buffer is partial or not.
 # A line is treated as partial if it does not ends with \n
-sub getline
-{
-	my $self = shift;
-	my ( $temp, $status, $size, $buffer, @lines );
+sub getline {
+    my $self = shift;
+    my ( $temp, $status, $size, $buffer, @lines );
 
-	$status = AZ_OK;
-	$size   = $self->buffer_size();
-	$temp   = \$status;
-	while ( $$temp !~ /\n/ && $status != AZ_STREAM_END )
-	{
-		( $temp, $status ) = $self->{member}->readChunk($size);
-		if ( $status != AZ_OK && $status != AZ_STREAM_END )
-		{
-			die "ERROR: Error reading chunk from archive - $status\n";
-		}
+    $status = AZ_OK;
+    $size   = $self->buffer_size();
+    $temp   = \$status;
+    while ( $$temp !~ /\n/ && $status != AZ_STREAM_END ) {
+        ( $temp, $status ) = $self->{member}->readChunk($size);
+        if ( $status != AZ_OK && $status != AZ_STREAM_END ) {
+            die "ERROR: Error reading chunk from archive - $status\n";
+        }
 
-		$buffer .= $$temp;
-	}
+        $buffer .= $$temp;
+    }
 
-	@lines = split ( /\n/, $buffer );
-	$self->{line_no}++;
-	if ( $#lines == -1 )
-	{
-		return ( $#{ $self->{lines} } == -1 ) 
-		  ? undef
-		  : shift ( @{ $self->{lines} } );
-	}
+    @lines = split( /\n/, $buffer );
+    $self->{line_no}++;
+    if ( $#lines == -1 ) {
+        return ( $#{ $self->{lines} } == -1 )
+          ? undef
+          : shift( @{ $self->{lines} } );
+    }
 
-	$self->{lines}->[ $#{ $self->{lines} } ] .= shift (@lines)
-	  if $self->{partial};
+    $self->{lines}->[ $#{ $self->{lines} } ] .= shift(@lines)
+      if $self->{partial};
 
-	splice( @{ $self->{lines} }, @{ $self->{lines} }, 0, @lines );
-	$self->{partial} = !( $buffer =~ /\n$/ );
-	return shift ( @{ $self->{lines} } );
+    splice( @{ $self->{lines} }, @{ $self->{lines} }, 0, @lines );
+    $self->{partial} = !( $buffer =~ /\n$/ );
+    return shift( @{ $self->{lines} } );
 }
 
 =item read($buffer, $num_bytes_to_read)
@@ -257,24 +242,21 @@ Returns the no. of bytes read. C<undef> on error, 0 on eof, I<e.g.>:
 #
 # All these $_ are required to emulate read().
 #
-sub read
-{
-	my $self = $_[0];
-	my $size = $_[2];
-	my ( $temp, $status, $ret );
+sub read {
+    my $self = $_[0];
+    my $size = $_[2];
+    my ( $temp, $status, $ret );
 
-	( $temp, $status ) = $self->{member}->readChunk($size);
-	if ( $status != AZ_OK && $status != AZ_STREAM_END )
-	{
-		$_[1] = undef;
-		$ret = undef;
-	}
-	else
-	{
-		$_[1] = $$temp;
-		$ret = length($$temp);
-	}
-	return $ret;
+    ( $temp, $status ) = $self->{member}->readChunk($size);
+    if ( $status != AZ_OK && $status != AZ_STREAM_END ) {
+        $_[1] = undef;
+        $ret = undef;
+    }
+    else {
+        $_[1] = $$temp;
+        $ret = length($$temp);
+    }
+    return $ret;
 }
 
 1;
